@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2007 by PCMan (Hong Jen Yee) <pcman.tw@gmail.com>       *
- *   Copyright (C) 2023 Ingo Brückl                                        *
+ *   Copyright (C) 2023-2024 Ingo Brückl                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -251,7 +251,11 @@ static gboolean on_draw_event( GtkWidget* widget, cairo_t *cr )
 {
 
     ImageView* iv = (ImageView*)widget;
+#if GTK_CHECK_VERSION(2, 20, 0)
     if ( gtk_widget_get_mapped(widget) )
+#else
+    if ( GTK_WIDGET_MAPPED(widget) )
+#endif
         image_view_paint( iv, cr );
     return FALSE;
 
@@ -365,8 +369,13 @@ void image_view_set_scale( ImageView* iv, gdouble new_scale, GdkInterpType type
     gdouble vadj_value = gtk_adjustment_get_value(iv->vadj);
 
     // if the pointer is not inside the window...
+#if GTK_CHECK_VERSION(2, 14, 0)
     if (xPos < hadj_value || xPos > hadj_value + gtk_adjustment_get_page_size(iv->hadj) ||
         yPos < vadj_value || yPos > vadj_value + gtk_adjustment_get_page_size(iv->vadj))
+#else
+    if (xPos < hadj_value || xPos > hadj_value + iv->hadj->page_size ||
+        yPos < vadj_value || yPos > vadj_value + iv->vadj->page_size)
+#endif
     {
         // ...pretend that it is over the center of the image
         xPos = iv->img_area.width / 2;
