@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2007, 2008 by PCMan (Hong Jen Yee) <pcman.tw@gmail.com> *
- *   Copyright (C) 2023 by Ingo Brückl                                     *
+ *   Copyright (C) 2023-2024 by Ingo Brückl                                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -84,6 +84,7 @@ static void on_rotate_clockwise( GtkWidget* btn, MainWin* mw );
 static void on_rotate_counterclockwise( GtkWidget* btn, MainWin* mw );
 static void on_save_as( GtkWidget* btn, MainWin* mw );
 static void on_save( GtkWidget* btn, MainWin* mw );
+static void on_copy( GtkWidget* btn, MainWin* mw );
 static void cancel_slideshow(MainWin* mw);
 static gboolean next_slide(MainWin* mw);
 static void on_slideshow_menu( GtkMenuItem* item, MainWin* mw );
@@ -854,6 +855,13 @@ void on_flip_horizontal( GtkWidget* btn, MainWin* mw )
 
 /* end of rotate & flip */
 
+void on_copy( GtkWidget* btn, MainWin* mw )
+{
+    GtkClipboard* clipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
+
+    gtk_clipboard_set_image( clipboard, mw->pix );
+}
+
 void on_save_as( GtkWidget* btn, MainWin* mw )
 {
     char *file, *type;
@@ -1076,7 +1084,11 @@ gboolean on_mouse_move( GtkWidget* widget, GdkEventMotion* evt, MainWin* mw )
 gboolean on_button_release( GtkWidget* widget, GdkEventButton* evt, MainWin* mw )
 {
     mw->dragging = FALSE;
+#if GTK_CHECK_VERSION(2, 14, 0)
     gdk_window_set_cursor( gtk_widget_get_window(widget), NULL );
+#else
+    gdk_window_set_cursor( GTK_IS_WIDGET(widget) ? widget->window : NULL, NULL );
+#endif
     return FALSE;
 }
 
@@ -1115,6 +1127,7 @@ gboolean on_scroll_event( GtkWidget* widget, GdkEventScroll* evt, MainWin* mw )
 
 gboolean on_key_press_event(GtkWidget* widget, GdkEventKey * key)
 {
+    guint modifiers = gtk_accelerator_get_default_mod_mask();
     MainWin* mw = (MainWin*)widget;
     switch( key->keyval )
     {
@@ -1170,6 +1183,11 @@ gboolean on_key_press_event(GtkWidget* widget, GdkEventKey * key)
         case GDK_A:
             on_save_as( NULL, mw );
             break;
+        case GDK_c:
+        case GDK_C:
+            if ((key->state & modifiers) == GDK_CONTROL_MASK)
+                on_copy( NULL, mw );
+            break;
         case GDK_l:
         case GDK_L:
             on_rotate_counterclockwise( NULL, mw );
@@ -1533,7 +1551,7 @@ void on_about( GtkWidget* menu, MainWin* mw )
     gtk_about_dialog_set_version ( (GtkAboutDialog*)about_dlg, VERSION );
     gtk_about_dialog_set_program_name ( (GtkAboutDialog*)about_dlg, _( "GPicView" ) );
     gtk_about_dialog_set_logo_icon_name ( (GtkAboutDialog*)about_dlg, "gpicview" );
-    gtk_about_dialog_set_copyright ( (GtkAboutDialog*)about_dlg, _( "Copyright (C) 2007 - 2023" ) );
+    gtk_about_dialog_set_copyright ( (GtkAboutDialog*)about_dlg, _( "Copyright (C) 2007 - 2025" ) );
     gtk_about_dialog_set_comments ( (GtkAboutDialog*)about_dlg, _( "Lightweight image viewer from LXDE project" ) );
     gtk_about_dialog_set_license ( (GtkAboutDialog*)about_dlg, "GPicView\n\nCopyright (C) 2007 Hong Jen Yee (PCMan)\n\nThis program is free software; you can redistribute it and/or\nmodify it under the terms of the GNU General Public License\nas published by the Free Software Foundation; either version 2\nof the License, or (at your option) any later version.\n\nThis program is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\nGNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License\nalong with this program; if not, write to the Free Software\nFoundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA." );
     gtk_about_dialog_set_website ( (GtkAboutDialog*)about_dlg, "http://wiki.lxde.org/en/GPicView" );
