@@ -59,7 +59,6 @@ typedef struct _MainWin
     GdkPixbufAnimationIter* animation_iter;
     guint animation_timeout;
 
-    GtkWidget* zoom_btn;
     GtkWidget* img_view;
     GtkWidget* scroll;
     GtkWidget* evt_box;
@@ -70,11 +69,18 @@ typedef struct _MainWin
     GtkWidget* btn_flip_h;
     GtkWidget* btn_orig;
     GtkWidget* btn_fit;
+    GtkWidget* btn_play_stop;
+    GtkWidget* img_play_stop;
     GtkWidget* percent;
     GdkCursor* hand_cursor;
+
+    GtkAllocation scroll_allocation;
+
     ZoomMode zoom_mode;
     gboolean full_screen;
-
+    gboolean slideshow_running;
+    gboolean slideshow_cancelled;
+    guint slide_timeout;
     gboolean dragging;
     double scale;
     int drag_old_x;
@@ -87,6 +93,8 @@ GtkWidget* main_win_new();
 
 gboolean main_win_open( MainWin* mw, const char* file_path, ZoomMode zoom );
 
+void main_win_start_slideshow( MainWin* mw );
+
 void main_win_close( MainWin* mw );
 
 gboolean main_win_save( MainWin* mw, const char* file_path, const char* type, gboolean confirm );
